summaryrefslogtreecommitdiff
path: root/gtk2_ardour/mixer_strip.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2009-05-17 17:05:56 +0000
committerPaul Davis <paul@linuxaudiosystems.com>2009-05-17 17:05:56 +0000
commit5a4d340b42ae2485d4bde4421f84c6220b24cab4 (patch)
treec77a444a49efc991ac1c450f938454962741a875 /gtk2_ardour/mixer_strip.cc
parentd1f09a9403d836c5b7b95eb56fc72d255db50ff6 (diff)
Das BlinkenSendButtons
git-svn-id: svn://localhost/ardour2/branches/3.0@5097 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/mixer_strip.cc')
-rw-r--r--gtk2_ardour/mixer_strip.cc9
1 files changed, 7 insertions, 2 deletions
diff --git a/gtk2_ardour/mixer_strip.cc b/gtk2_ardour/mixer_strip.cc
index 4d8d196b4b..fdc1e2f39b 100644
--- a/gtk2_ardour/mixer_strip.cc
+++ b/gtk2_ardour/mixer_strip.cc
@@ -294,7 +294,6 @@ MixerStrip::init ()
/* ditto for this button and busses */
- show_sends_button->set_name ("MixerRecordEnableButton");
show_sends_button->signal_button_press_event().connect (mem_fun(*this, &RouteUI::show_sends_press), false);
show_sends_button->signal_button_release_event().connect (mem_fun(*this, &RouteUI::show_sends_release));
@@ -1506,10 +1505,12 @@ MixerStrip::switch_io (boost::shared_ptr<Route> target)
/* don't change the display for the target or the master bus */
return;
} else if (!is_track() && show_sends_button) {
/* make sure our show sends button is inactive,
since we're not the target.
*/
+ send_blink_connection.disconnect ();
show_sends_button->set_active (false);
+ show_sends_button->set_state (STATE_NORMAL);
}
if (!target) {
@@ -1537,9 +1538,12 @@ MixerStrip::switch_io (boost::shared_ptr<Route> target)
panner_ui().setup_pan ();
}
+
void
MixerStrip::revert_to_default_display ()
{
+ show_sends_button->set_active (false);
+
if (_current_send) {
_current_send->set_metering (false);
_current_send.reset();
@@ -1550,3 +1554,4 @@ MixerStrip::revert_to_default_display ()
panner_ui().set_io (_route);
panner_ui().setup_pan ();
}
+
@@ -1506,10 +1505,12 @@ MixerStrip::switch_io (boost::shared_ptr<Route> target)
return;
} else if (!is_track() && show_sends_button) {
- /* make sure our show sends button is inactive,
+ /* make sure our show sends button is inactive, and we no longer blink,
since we're not the target.
*/